Other functionalities
=====================

Besides the use-cases described in previous sections, we also need
several others for the web application to work.

.. toctree::
   :maxdepth: 2

   use-case.rst
